@@ -1,7 +1,7 @@
 package Galileo;
 use Mojo::Base 'Mojolicious';
 
-our $VERSION = 0.011;
+our $VERSION = 0.012;
 $VERSION = eval $VERSION;
 
 use File::Basename 'dirname';
@@ -190,6 +190,9 @@ sub startup {
   $if_admin->any( '/admin/user/:name' )->to('admin#user');
   $if_admin->websocket( '/store/user' )->to('admin#store_user');
   $if_admin->websocket( '/remove/page' )->to('admin#remove_page');
+
+  ## Additional Plugins ##
+  $app->plugin('ConsoleLogger') if $ENV{GALILEO_CONSOLE_LOGGER};
 }
 
 1;
@@ -235,6 +238,10 @@ This is the directory where L<Galileo> expects additional files. These include t
 
 This is the full path to a configuration file. The default is a file named F<galileo.conf> in the C<GALILEO_HOME> path, however this file need not actually exist, defaults may be used instead. This file need not be written by hand, it may be generated by the C<galileo config> command.
 
+=item C<GALILEO_CONSOLE_LOGGER>
+
+Use L<Mojolicious::Plugin::ConsoleLogger> to get additional state information and logger output sent to the browser console.
+
 =back
 
 =head2 The F<galileo> command line application
@@ -255,13 +262,17 @@ The C<--force> option may be passed to overwrite any configuration file in the c
 
  $ galileo setup
 
-This step is required. Run C<galileo setup> to setup a database. It will use the default DBI settings (SQLite) or whatever is setup in the C<GALILEO_CONFIG> configuration file.
+This step is required after both installation and upgrading Galileo. Running C<galileo setup> will deploy or upgrade the database used by your Galileo site. It will use the default DBI settings (SQLite) or whatever is setup in the C<GALILEO_CONFIG> configuration file.
+
+Warning: As usual, proper care should be taken when upgrading a database. This mechanism is rather new and while it should be safe, the author makes no promises about anything yet! Backup all files before upgrading!
+
+Note that the database deployment tools may emit debugging information unexpectedly, especially messages about "overwriting" and some internal "peek" information. These message are harmless, but as yet cannot be suppressed. 
 
 =head1 RUNNING THE APPLICATION
 
  $ galileo daemon
 
-After the database is has been setup, you can run C<galileo daemon> to start the server. 
+After the database has been setup, you can run C<galileo daemon> to start the server. 
 
 You may also use L<morbo> (Mojolicious' development server) or L<hypnotoad> (Mojolicious' production server). You may even use any other server that Mojolicious supports, however for full functionality it must support websockets. When doing so you will need to know the full path to the C<galileo> application. A useful recipe might be
 
